@@ -50,7 +50,7 @@ void CloseLogMenu (GtkWidget * widget, gpointer user_data);
 void change_log_menu (GtkWidget * widget, gpointer user_data);
 void CalendarMenu (GtkWidget * widget, gpointer user_data);
 void MonitorMenu (GtkWidget* widget, gpointer user_data); 
-void create_zoom_view (GtkWidget * widget, gpointer user_data);
+void create_zoom_view (GtkWidget *widget, gpointer data);
 void UserPrefsDialog(GtkWidget * widget, gpointer user_data);
 void AboutShowWindow (GtkWidget* widget, gpointer user_data);
 void CloseApp (void);
@@ -76,6 +76,10 @@ Log *OpenLogFile (char *);
 GtkWidget *new_pixmap_from_data (char  **, GdkWindow *, GdkColor *);
 GtkWidget *create_menu (char *item[], int n);
 void SaveUserPrefs(UserPrefsStruct *prefs);
+void close_zoom_view (GtkWidget *widget, gpointer client_data);
+
+static void toggle_calendar (void);
+static void toggle_zoom (void);
 
 /*
  *    ,-------.
@@ -84,57 +88,34 @@ void SaveUserPrefs(UserPrefsStruct *prefs);
  */
 
 
-GnomeUIInfo file_menu[] = {
-        {GNOME_APP_UI_ITEM, N_("Open log..."), 
-	 N_("Open log"), LoadLogMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("Export log..."), 
-	 N_("Export log"), StubCall, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("Close log"), 
-	 N_("Close log"), CloseLogMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("Switch log"), 
-	 N_("Switch log"), change_log_menu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("Monitor..."), 
-	 N_("Monitor log"), MonitorMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("Exit"), 
-	 N_("Exit program"), ExitProg, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'E', GDK_CONTROL_MASK, NULL},
+GnomeUIInfo log_menu[] = {
+	GNOMEUIINFO_MENU_OPEN_ITEM(LoadLogMenu, NULL),
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM(StubCall, NULL),
+	GNOMEUIINFO_SEPARATOR,
+        { GNOME_APP_UI_ITEM, N_("S_witch Log"), 
+	  N_("Switch log"), change_log_menu, NULL, NULL,
+          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+        { GNOME_APP_UI_ITEM, N_("_Monitor..."), 
+	  N_("Monitor Log"), MonitorMenu, NULL, NULL,
+          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
+	GNOMEUIINFO_SEPARATOR,
+        { GNOME_APP_UI_ITEM, N_("_Properties"), 
+	  N_("Show Log Properties"), LogInfo, NULL, NULL,
+          GNOME_APP_PIXMAP_NONE, NULL, 'I', GDK_CONTROL_MASK, NULL},
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_CLOSE_ITEM(CloseLogMenu, NULL),
+	GNOMEUIINFO_MENU_QUIT_ITEM(ExitProg, NULL),
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
 GnomeUIInfo view_menu[] = {
-        {GNOME_APP_UI_ITEM, N_("Calendar"), 
-	 N_("Show calendar log"), CalendarMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 'C', GDK_CONTROL_MASK, NULL},
-        {GNOME_APP_UI_ITEM, N_("Log stats"), 
-	 N_("Show log stats"), LogInfo, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 'I', GDK_CONTROL_MASK, NULL},
-        {GNOME_APP_UI_ITEM, N_("Zoom"), 
-	 N_("Show line info"), create_zoom_view, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 'Z', GDK_CONTROL_MASK, NULL},
-       /* {GNOME_APP_UI_ITEM, N_("Preferences..."), 
-	 N_("Show user preferences"), UserPrefsDialog, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 'P', GDK_CONTROL_MASK, NULL},*/
-	/* As of now  user preference dialog does nothing except 
-        the hostname width adjustment in displaying */
+        { GNOME_APP_UI_TOGGLEITEM, N_("_Calendar"), N_("Show Calendar Log"), toggle_calendar, 
+	  NULL, NULL, GNOME_APP_PIXMAP_NONE, NULL, 'L', GDK_CONTROL_MASK, NULL },
+        { GNOME_APP_UI_TOGGLEITEM, N_("_Entry Detail"), N_("Show Entry Detail"), toggle_zoom, 
+	  NULL, NULL, GNOME_APP_PIXMAP_NONE, NULL, 'D', GDK_CONTROL_MASK, NULL },
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
-#if 0
-GnomeUIInfo filter_menu[] = {
-        {GNOME_APP_UI_ITEM, N_("Select...               "), 
-	 N_("Select log events"), StubCall, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, N_("Filter..                "), 
-	 N_("Filter log events"), StubCall, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
-};
-#endif
 
 GnomeUIInfo help_menu[] = {
 	GNOMEUIINFO_HELP("gnome-system-log"),
@@ -146,10 +127,10 @@ GnomeUIInfo help_menu[] = {
 };
 
 GnomeUIInfo main_menu[] = {
-	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+        { GNOME_APP_UI_SUBTREE_STOCK, N_("_Log"), NULL,
+          log_menu, NULL, NULL, (GnomeUIPixmapType) 0,
+          NULL, 0, (GdkModifierType) 0, NULL },
 	GNOMEUIINFO_MENU_VIEW_TREE(view_menu),
-/*        {GNOME_APP_UI_SUBTREE, N_("F_ilter"), NULL,  filter_menu, NULL, NULL, */
-/*         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}, */
 	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
@@ -188,11 +169,14 @@ struct poptOption options[] = { {
 	NULL,
 } };
 
+extern GtkWidget *CalendarDialog;
+extern GtkWidget *zoom_dialog;
 extern GdkGC *gc;
 extern Log *curlog, *loglist[];
 extern int numlogs, curlognum;
 extern int loginfovisible, calendarvisible;
 extern int cursor_visible;
+extern int zoom_visible;
 extern PangoLayout *log_layout;
 
 /* ----------------------------------------------------------------------
@@ -359,7 +343,7 @@ void
 CreateMainWin ()
 {
    GtkWidget *canvas;
-   GtkWidget *w, *box, *table, *hbox2;
+   GtkWidget *w, *vbox, *table, *hbox, *hbox_date;
    GtkWidget *padding;
    GtkLabel *label;
    GtkObject *adj;
@@ -367,7 +351,7 @@ CreateMainWin ()
 
    /* Create App */
 
-   app = gnome_app_new ("Logview", _("System Log Viewer"));
+   app = gnome_app_new ("gnome-system-log", _("System Log Viewer"));
 
    gtk_container_set_border_width ( GTK_CONTAINER (app), 0);
    gtk_window_set_default_size ( GTK_WINDOW (app), LOG_CANVAS_W, LOG_CANVAS_H);
@@ -383,31 +367,25 @@ CreateMainWin ()
    /* Create menus */
    gnome_app_create_menus (GNOME_APP (app), main_menu);
 
-   box = gtk_vbox_new (FALSE, 0);
-   gnome_app_set_contents (GNOME_APP (app), box);
+   vbox = gtk_vbox_new (FALSE, 0);
+   gnome_app_set_contents (GNOME_APP (app), vbox);
 
    /* Deactivate unfinished items */
-   gtk_widget_set_state (file_menu[1].widget, GTK_STATE_INSENSITIVE);
+   gtk_widget_set_state (log_menu[1].widget, GTK_STATE_INSENSITIVE);
    if (numlogs < 2)
-     gtk_widget_set_state (file_menu[3].widget, GTK_STATE_INSENSITIVE);
-#if 0
-   gtk_widget_set_state (filter_menu[0].widget, GTK_STATE_INSENSITIVE);
-   gtk_widget_set_state (filter_menu[1].widget, GTK_STATE_INSENSITIVE);
-#endif
+     gtk_widget_set_state (log_menu[3].widget, GTK_STATE_INSENSITIVE);
 
    /* Create main canvas and scroll bars */
    table = gtk_table_new (2, 2, FALSE);
    gtk_widget_show (table);
 
    viewport = gtk_viewport_new (NULL, NULL);
-   gtk_widget_set_usize (viewport, LOG_CANVAS_W, 0); 
+   gtk_widget_set_size_request (viewport, LOG_CANVAS_W, 0); 
    gtk_widget_show (viewport);
                
    canvas = gtk_drawing_area_new ();
-   /*gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, LOG_CANVAS_H); */
    gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W,
 			  LOG_CANVAS_H); 
-   /*gtk_widget_set_usize ( GTK_WIDGET (canvas), LOG_CANVAS_W, LOG_CANVAS_H);*/
    gtk_container_add (GTK_CONTAINER (viewport), canvas);
    gtk_table_attach (GTK_TABLE (table), viewport, 0, 1, 0, 1,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -443,15 +421,11 @@ CreateMainWin ()
    gtk_widget_show (main_win_scrollbar);  
 
 
-   gtk_box_pack_start (GTK_BOX (box), table, TRUE, TRUE, 0);
+   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
    
    /*  Install event handlers */
    gtk_signal_connect (GTK_OBJECT (canvas), "expose_event",
 		       GTK_SIGNAL_FUNC (log_repaint), NULL);
-#if 0
-   gtk_signal_connect (GTK_OBJECT (canvas), "motion_notify_event",
-		       GTK_SIGNAL_FUNC (PointerMoved), NULL);
-#endif
    gtk_signal_connect (GTK_OBJECT (app), "key_press_event",
 		       GTK_SIGNAL_FUNC (HandleLogKeyboard), NULL);
    gtk_signal_connect (GTK_OBJECT (canvas), "button_press_event",
@@ -469,47 +443,48 @@ CreateMainWin ()
    gtk_widget_set_events (app, GDK_KEY_PRESS_MASK);
 
 
-   /*gtk_widget_set_style (canvas, cfg->black_bg_style); */
    gtk_widget_set_style (canvas, cfg->white_bg_style);
    gtk_widget_show (canvas);
 
 
    /* Create status area at bottom */
-   hbox2 = gtk_hbox_new (FALSE, 2);
-   gtk_container_set_border_width ( GTK_CONTAINER (hbox2), 3);
+   hbox = gtk_hbox_new (FALSE, 2);
+   gtk_container_set_border_width ( GTK_CONTAINER (hbox), 3);
 
    label = (GtkLabel *)gtk_label_new (_("Filename: "));
    gtk_label_set_justify (label, GTK_JUSTIFY_LEFT);
-   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (label), FALSE, FALSE, 0);
+   gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, 0);
    gtk_widget_show (GTK_WIDGET (label));  
 
    filename_label = (GtkLabel *)gtk_label_new ("");
    gtk_widget_show ( GTK_WIDGET (filename_label));  
    gtk_label_set_justify (label, GTK_JUSTIFY_LEFT);
-   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (filename_label), 
+   gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (filename_label), 
 		       FALSE, FALSE, 0);
    
-   /* Add padding to right justify */
-   padding = gtk_label_new (" ");
-   gtk_widget_show (padding);
-   gtk_box_pack_start (GTK_BOX (hbox2), padding, TRUE, TRUE, 0);
-
-   label = (GtkLabel *)gtk_label_new (_("Date: "));
-   gtk_label_set_justify (label, GTK_JUSTIFY_RIGHT);
-   gtk_widget_set_usize (GTK_WIDGET(label), 40, -1);
-   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (label), FALSE, FALSE, 0);
-   gtk_widget_show (GTK_WIDGET (label));  
+   hbox_date = gtk_hbox_new (FALSE, 2);
+   gtk_container_set_border_width ( GTK_CONTAINER (hbox_date), 3);
 
    date_label = (GtkLabel *)gtk_label_new ("");
-   gtk_widget_show (GTK_WIDGET (date_label));  
-   gtk_widget_set_usize (GTK_WIDGET (label), 60, -1);
-   gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (date_label), FALSE, FALSE, 0);
+   gtk_widget_show (GTK_WIDGET (date_label));
+   /* gtk_widget_set_size_request (GTK_WIDGET (label), 60, -1); */
+   gtk_box_pack_end (GTK_BOX (hbox_date), GTK_WIDGET (date_label), 
+		     TRUE, TRUE, 0);
 
-   gtk_widget_show (hbox2);
 
-   gtk_box_pack_start (GTK_BOX (box), hbox2, FALSE, FALSE, 0);
+   label = (GtkLabel *)gtk_label_new (_("Last Modified: "));
+   gtk_label_set_justify (label, GTK_JUSTIFY_RIGHT);
+   gtk_box_pack_end (GTK_BOX (hbox_date), GTK_WIDGET (label), 
+		     FALSE, FALSE, 0);
+   gtk_widget_show (GTK_WIDGET (label));  
 
-   gtk_widget_show (box);
+
+   gtk_widget_show (hbox_date);
+   gtk_box_pack_end (GTK_BOX (hbox), hbox_date, FALSE, FALSE, 0);
+   gtk_widget_show (hbox);
+   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+
+   gtk_widget_show (vbox);
    gtk_widget_show (app);
 
 }
@@ -646,7 +621,6 @@ void set_scrollbar_size (int num_lines)
 {
   GtkObject *adj;
 
-  /*adj = gtk_adjustment_new ( curlog->ln, 0.0, num_lines+LINES_P_PAGE, 1.0, 10.0, (float) LINES_P_PAGE);*/
   adj = gtk_adjustment_new (-1, 0.0, num_lines,
 			    1.0, 10.0, (float) LINES_P_PAGE);
   gtk_range_set_adjustment (GTK_RANGE (main_win_scrollbar),
@@ -696,9 +670,9 @@ CloseLogMenu (GtkWidget * widget, gpointer user_data)
       if (loginfovisible)
 	 RepaintLogInfo (NULL, NULL);
       set_scrollbar_size (1);
-      gtk_widget_set_sensitive (file_menu[2].widget, FALSE); 
-      gtk_widget_set_sensitive (file_menu[4].widget, FALSE); 
-      for ( i = 0; i < 4; i++) 
+      gtk_widget_set_sensitive (log_menu[7].widget, FALSE); 
+      gtk_widget_set_sensitive (log_menu[4].widget, FALSE); 
+      for ( i = 0; i < 3; i++) 
          gtk_widget_set_sensitive (view_menu[i].widget, FALSE); 
       return;
    }
@@ -716,7 +690,7 @@ CloseLogMenu (GtkWidget * widget, gpointer user_data)
 
    /* Change menu entry if there is only one log */
    if (numlogs < 2)
-     gtk_widget_set_state (file_menu[3].widget, GTK_STATE_INSENSITIVE);
+     gtk_widget_set_state (log_menu[3].widget, GTK_STATE_INSENSITIVE);
 
    set_scrollbar_size (curlog->lstats.numlines);
 }
@@ -776,10 +750,10 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
 	 {
 	   int i;
 	   if (numlogs >= 2)
-	     gtk_widget_set_sensitive (file_menu[3].widget, TRUE);
-	   gtk_widget_set_sensitive (file_menu[2].widget, TRUE);
-	   gtk_widget_set_sensitive (file_menu[4].widget, TRUE);
-	   for ( i = 0; i < 4; i++) 
+	     gtk_widget_set_sensitive (log_menu[3].widget, TRUE);
+	   gtk_widget_set_sensitive (log_menu[7].widget, TRUE);
+	   gtk_widget_set_sensitive (log_menu[4].widget, TRUE);
+	   for ( i = 0; i < 3; i++) 
 	     gtk_widget_set_sensitive (view_menu[i].widget, TRUE);
 	 } 
       }
@@ -1028,3 +1002,24 @@ void SaveUserPrefs(UserPrefsStruct *prefs)
     			  prefs->message_column_width, NULL);
 
 }
+
+static void 
+toggle_calendar (void)
+{
+    if (calendarvisible) {
+	calendarvisible = FALSE;
+	gtk_widget_hide (CalendarDialog);
+    }
+    else
+	CalendarMenu (app, NULL);
+}
+
+static void
+toggle_zoom (void)
+{
+    if (zoom_visible) {
+	close_zoom_view (app, NULL);
+    }
+    else
+	create_zoom_view (NULL, NULL);
+}
